@@ -170,8 +170,10 @@ pub mod paginated_remote_command_event_list;
 pub use self::paginated_remote_command_event_list::PaginatedRemoteCommandEventList;
 pub mod paginated_remote_control_command_list;
 pub use self::paginated_remote_control_command_list::PaginatedRemoteControlCommandList;
-pub mod paginated_system_task_list;
-pub use self::paginated_system_task_list::PaginatedSystemTaskList;
+pub mod paginated_task_list;
+pub use self::paginated_task_list::PaginatedTaskList;
+pub mod paginated_task_status_list;
+pub use self::paginated_task_status_list::PaginatedTaskStatusList;
 pub mod paginated_telemetry_event_polymorphic_list;
 pub use self::paginated_telemetry_event_polymorphic_list::PaginatedTelemetryEventPolymorphicList;
 pub mod paginated_user_list;
@@ -204,6 +206,8 @@ pub mod patched_printer_profile_request;
 pub use self::patched_printer_profile_request::PatchedPrinterProfileRequest;
 pub mod patched_remote_control_command_request;
 pub use self::patched_remote_control_command_request::PatchedRemoteControlCommandRequest;
+pub mod patched_task_status_request;
+pub use self::patched_task_status_request::PatchedTaskStatusRequest;
 pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod print_job_event;
@@ -256,16 +260,16 @@ pub mod software_enum;
 pub use self::software_enum::SoftwareEnum;
 pub mod status_enum;
 pub use self::status_enum::StatusEnum;
-pub mod system_task;
-pub use self::system_task::SystemTask;
-pub mod system_task_request;
-pub use self::system_task_request::SystemTaskRequest;
-pub mod system_task_status;
-pub use self::system_task_status::SystemTaskStatus;
-pub mod system_task_status_request;
-pub use self::system_task_status_request::SystemTaskStatusRequest;
-pub mod system_task_type;
-pub use self::system_task_type::SystemTaskType;
+pub mod task;
+pub use self::task::Task;
+pub mod task_request;
+pub use self::task_request::TaskRequest;
+pub mod task_status;
+pub use self::task_status::TaskStatus;
+pub mod task_status_request;
+pub use self::task_status_request::TaskStatusRequest;
+pub mod task_type;
+pub use self::task_type::TaskType;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_event_type_enum;
